LlamaStateSeqFlags

Struct LlamaStateSeqFlags 

pub struct LlamaStateSeqFlags(/* private fields */);
Flags for state sequence operations.

These flags control what parts of the state are included when saving/restoring sequence state.

Implementations

Source

impl LlamaStateSeqFlags

pub const PARTIAL_ONLY: LlamaStateSeqFlags

Work only with partial states, such as SWA KV cache or recurrent cache (e.g. Mamba).

This flag is useful when you only want to save/restore the recurrent state without affecting the KV cache.

pub const fn empty() -> LlamaStateSeqFlags

Create an empty flags set.

pub const fn bits(&self) -> u32

Get the raw flags value.

pub const fn contains(&self, other: LlamaStateSeqFlags) -> bool

Check if a flag is set.