pub struct LlamaStateSeqFlags(/* private fields */);Expand description
Flags for state sequence operations.
These flags control what parts of the state are included when saving/restoring sequence state.
Implementations
Sourceimpl LlamaStateSeqFlags
impl LlamaStateSeqFlags
Sourcepub const PARTIAL_ONLY: LlamaStateSeqFlags
pub const PARTIAL_ONLY: LlamaStateSeqFlags
Work only with partial states, such as SWA KV cache or recurrent cache (e.g. Mamba).
This flag is useful when you only want to save/restore the recurrent state without affecting the KV cache.
Sourcepub const fn empty() -> LlamaStateSeqFlags
pub const fn empty() -> LlamaStateSeqFlags
Create an empty flags set.
Sourcepub const fn contains(&self, other: LlamaStateSeqFlags) -> bool
pub const fn contains(&self, other: LlamaStateSeqFlags) -> bool
Check if a flag is set.